@@ -1,6 +1,10 @@
+// SPDX-FileCopyrightText: 2018 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 package langselector
 
-import "github.com/godbus/dbus"
+import "github.com/godbus/dbus/v5"
 
 const (
 	dbusDest      = "com.deepin.daemon.LangSelector"
