@@ -1,9 +1,13 @@
+// SPDX-FileCopyrightText: 2018 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 package notify
 
 import (
 	"deepin-upgrade-manager/pkg/module/util"
 
-	"github.com/godbus/dbus"
+	"github.com/godbus/dbus/v5"
 )
 
 var msgRollBack = util.Tr("System Recovery")
