@@ -1,3 +1,7 @@
+// SPDX-FileCopyrightText: 2018 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 package repo
 
 import (
@@ -14,7 +18,6 @@ type Repository interface {
 	List() (branch.BranchList, error)
 	ListByName(branchName string, offset, limit int) (branch.BranchList, int, error)
 	Snapshot(branchName, dstDir string) error
-	SnapshotSub(branchName, subDir, dstDir string) error
 	Commit(branchName, subject, dataDir string) error
 	Diff(baseBranch, targetBranch, dstFile string) error
 	Cat(branchName, filepath, dstFile string) error
