@@ -95,6 +95,7 @@ const (
 	_STATE_TY_FAILED_VERSION_DELETE
 	_STATE_TY_FAILED_NO_VERSION
 	_STATE_TY_FAILED_EXIT_SIGNAL
+	_STATE_TY_FAILED_UPDATE_INITRD
 	_STATE_TY_RUNING stateType = 1
 )
 
@@ -625,6 +626,12 @@ func (c *Upgrader) Rollback(version string,
 		c.UpdateProgress(100)
 	} else {
 		c.SendingSignal(evHandler, _OP_TY_ROLLBACK_PREPARING_SET_WAITTIME, _STATE_TY_RUNING, version, "")
+		out, err := exec.Command("/usr/sbin/deepin-boot-kit", "--action=mkinitrd").CombinedOutput()
+		if err != nil {
+			logger.Warning("update initrd failed:", string(out))
+			exitCode = _STATE_TY_FAILED_UPDATE_INITRD
+			goto failure
+		}
 		if len(c.rootMP) == 1 {
 			grubManager, _ := grub.LoadGrubParams()
 			newTitle := c.GrubTitle(backVersion)
@@ -744,6 +751,10 @@ func (c *Upgrader) getFilterList(filterlist, sublist []string) []string {
 					filterList = append(filterList, src, dst)
 				}
 			}
+			if fs.Remote {
+				dst := util.TrimRootdir(c.rootMP, fs.DestPoint)
+				filterList = append(filterList, dst)
+			}
 		}
 	}
 	filtersMountInfo, err := mountinfo.GetFilterInfo(SelfMountPath)
@@ -1074,7 +1085,6 @@ func (c *Upgrader) copyRepoData(rootDir, dataDir string,
 				return err
 			}
 		}
-
 	}
 	return nil
 }
@@ -1173,7 +1183,7 @@ func (c *Upgrader) updateLoaclMount(snapDir string) (mountpoint.MountPointList,
 		return mountedPointList, err
 	}
 	for _, info := range c.fsInfo {
-		if info.SrcPoint == rootPartition || info.DestPoint == "/" {
+		if info.SrcPoint == rootPartition || info.DestPoint == "/" || info.Remote {
 			logger.Debugf("ignore mount point %s", info.DestPoint)
 			continue
 		}
